==> qbankmanager_0.9.29.orig.tar.gz: qbankmanager-0.9.29/src/kbanking/libs/kbanking.h <==
/***************************************************************************
 $RCSfile: kbanking.h,v $
                             -------------------
    cvs         : $Id: kbanking.h,v 1.24 2005/08/26 11:23:01 aquamaniac Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef QBANKMANAGER_BANKING_H
#define QBANKMANAGER_BANKING_H

#include <qbanking/qbanking.h>
#include <gwenhywfar/nettransportssl.h>

#include <qobject.h>
#include <list>

class KBanking;
class TransactionWindow;
class MainWindow;
class WaitCallback;

#include <qbanking/qbanking.h>

#include "app.h"
#include "report.h"
#include "flagstaff.h"


class KBanking: public App {
private:
  MainWindow *_mainWindow;
  GWEN_TYPE_UINT32 _lastWidgetId;
  AB_BANKING_LOGLEVEL _logLevel;
  FlagStaff *_flagStaff;

  std::list<RefPointer<TransactionWindow> > _tWindows;

  /* variables from config file */
  std::list<Report*> _reports;
  unsigned int _lastReportId;

  /* private functions */
  void _sampleReportModules();

protected:
  virtual void infoTransactionsChanged(Account *a);
  virtual std::string tr(const char *s);

public:
  KBanking(const char *appname,
           const char *fname=0,
           const char *name=0);
  virtual ~KBanking();


  int init();
  int fini();

  FlagStaff *flagStaff();

  virtual bool importContext(AB_IMEXPORTER_CONTEXT *ctx,
                             GWEN_TYPE_UINT32 flags);
  void setMainWindow(MainWindow *w);
  MainWindow * getMainWindow();

  bool setTabWidget(const QString &name);

  int executeQueue();

  void transfersUpdated();
  void standingOrdersUpdated();

  void rebuildExportMenu();

  void invokeHelp(const char *subject);

  void addTransactionWindow(TransactionWindow *w);
  void delTransactionWindow(TransactionWindow *w);
  void delTransactionWindows();

  Report *findReport(const char *name);
  std::list<Report*> getReports();

  GWEN_DB_NODE *findReportProfile(Report *r, const char *id);
  GWEN_DB_NODE *getReportProfiles(Report *r);
  /** takes over ownership of the given group */
  int addReportProfile(Report *r, GWEN_DB_NODE *db);
  void removeReportProfile(Report *r,
                           GWEN_DB_NODE *dbProfile);

};




#endif /* QBANKMANAGER_BANKING_H */

==> qbankmanager_0.9.37.orig.tar.gz: qbankmanager-0.9.37/src/kbanking/libs/kbanking.h <==
/***************************************************************************
 $RCSfile: kbanking.h,v $
                             -------------------
    cvs         : $Id: kbanking.h,v 1.31 2006/03/08 15:38:34 aquamaniac Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifndef QBANKMANAGER_BANKING_H
#define QBANKMANAGER_BANKING_H

#include <qbanking/qbanking.h>

#include <qobject.h>
#include <list>

class KBanking;
class TransactionWindow;
class MainWindow;
class WaitCallback;
class CfgModuleQbm;

#include <qbanking/qbanking.h>

#include "app.h"
#include "report.h"
#include "flagstaff.h"
#include "transfer.h"
#include "refpointer.h"


class KBanking: public App {
private:
  MainWindow *_mainWindow;
  GWEN_TYPE_UINT32 _lastWidgetId;
  AB_BANKING_LOGLEVEL _logLevel;
  FlagStaff *_flagStaff;
  CfgModuleQbm *_cfgModule;

  std::list<RefPointer<TransactionWindow> > _tWindows;

  /* variables from config file */
  std::list<Report*> _reports;
  bool _useColoursForCategoryText;
  unsigned int _lastReportId;

  /* private functions */
  void _sampleReportModules();
  int _newTransferJob(Transfer::TransferType tt,
                      RefPointer<Transfer> tmpl,
                      AB_JOB **retjob,
                      QWidget *parent=0);
  int _newTransfer(RefPointer<Transfer> tmpl=0, QWidget *parent=0);
  int _newDebitNote(RefPointer<Transfer> tmpl=0, QWidget *parent=0);
  int _newEuTransfer(RefPointer<Transfer> tmpl=0, QWidget *parent=0);

protected:
  virtual void infoTransactionsChanged(Account *a);

public:
  KBanking(const char *appname,
           const char *fname=0,
           const char *name=0);
  virtual ~KBanking();


  int init();
  int fini();

  FlagStaff *flagStaff();

  virtual bool importContext(AB_IMEXPORTER_CONTEXT *ctx,
                             GWEN_TYPE_UINT32 flags);
  void setMainWindow(MainWindow *w);
  MainWindow * getMainWindow();

  virtual std::string tr(const char *s);

  bool setTabWidget(const QString &name);

  int executeQueue(AB_IMEXPORTER_CONTEXT *ctx);

  void transfersUpdated();
  void standingOrdersUpdated();

  void rebuildExportMenu();

  void addTransactionWindow(TransactionWindow *w);
  void delTransactionWindow(TransactionWindow *w);
  void delTransactionWindows();

  bool useColoursForCategoryText() const;
  void setUseColoursForCategoryText(bool b);

  Report *findReport(const char *name);
  std::list<Report*> getReports();

  GWEN_DB_NODE *findReportProfile(Report *r, const char *id);
  GWEN_DB_NODE *getReportProfiles(Report *r);
  /** takes over ownership of the given group */
  int addReportProfile(Report *r, GWEN_DB_NODE *db);
  void removeReportProfile(Report *r,
                           GWEN_DB_NODE *dbProfile);


  int transferFromTemplate(RefPointer<Transaction> tmpl,
                           QWidget *parent);
  int euTransferFromTemplate(RefPointer<Transaction> tmpl,
                              QWidget *parent);
  int debitNoteFromTemplate(RefPointer<Transaction> tmpl,
                            QWidget *parent);



};




#endif /* QBANKMANAGER_BANKING_H */
